import React, { useState } from 'react';
import ReactSlidy from 'react-slidy';
import cx from 'classnames';
import IconCamera from '@s-ui/react-icons/lib/Camera';
export var IMAGE_SLIDER_COUNTER_POSITIONS = {
  BOTTOM_CENTER: 'bottomCenter',
  BOTTOM_LEFT: 'bottomLeft',
  BOTTOM_RIGHT: 'bottomRight'
};

var NO_OP = function NO_OP() {};

var TARGET_BLANK = '_blank';

var defaultLinkFactory = function defaultLinkFactory(_ref // eslint-disable-line
) {
  var href = _ref.href,
      target = _ref.target,
      className = _ref.className,
      children = _ref.children,
      key = _ref.key;
  return (
    /*#__PURE__*/
    React.createElement("a", {
      href: href,
      target: target,
      className: className,
      key: key
    }, children)
  );
};

var defaultCounterPatternFactory = function defaultCounterPatternFactory(_ref2) {
  var current = _ref2.current,
      total = _ref2.total;
  return current + "/" + total;
};
/**
 * @param {Array} images List given by props.images.
 * @return {Array} List of img elements.
 */


var getSlides = function getSlides(currentSlide, images, linkFactory) {
  if (images === void 0) {
    images = [];
  }

  return images.map(function (image, index) {
    var alt = image.alt,
        imageKey = image.key,
        link = image.link,
        src = image.src,
        _image$target = image.target,
        target = _image$target === void 0 ? TARGET_BLANK : _image$target,
        title = image.title;
    var key = imageKey ? imageKey + index : index;
    var img = /*#__PURE__*/React.createElement("img", {
      alt: alt,
      "aria-selected": currentSlide === index,
      className: "sui-ImageSlider-image",
      key: key,
      src: src,
      title: title
    });
    return link ? linkFactory({
      key: key,
      target: target,
      className: '',
      children: img,
      href: link
    }) : img;
  });
};

export default function ImageSlider(_ref3) {
  var _ref3$images = _ref3.images,
      images = _ref3$images === void 0 ? [] : _ref3$images,
      _ref3$handleClick = _ref3.handleClick,
      handleClick = _ref3$handleClick === void 0 ? NO_OP : _ref3$handleClick,
      _ref3$sliderOptions = _ref3.sliderOptions,
      sliderOptions = _ref3$sliderOptions === void 0 ? {} : _ref3$sliderOptions,
      _ref3$linkFactory = _ref3.linkFactory,
      linkFactory = _ref3$linkFactory === void 0 ? defaultLinkFactory : _ref3$linkFactory,
      _ref3$enableCounter = _ref3.enableCounter,
      enableCounter = _ref3$enableCounter === void 0 ? false : _ref3$enableCounter,
      _ref3$counterPosition = _ref3.counterPosition,
      counterPosition = _ref3$counterPosition === void 0 ? IMAGE_SLIDER_COUNTER_POSITIONS.BOTTOM_RIGHT : _ref3$counterPosition,
      _ref3$counterIcon = _ref3.counterIcon,
      counterIcon = _ref3$counterIcon === void 0 ? IconCamera : _ref3$counterIcon,
      _ref3$counterPatternF = _ref3.counterPatternFactory,
      counterPatternFactory = _ref3$counterPatternF === void 0 ? defaultCounterPatternFactory : _ref3$counterPatternF;

  var _useState = useState(sliderOptions.initialSlide || 0),
      currentSlide = _useState[0],
      setCurrentSlide = _useState[1];

  var slides = getSlides(currentSlide, images, linkFactory);
  var hasSingleImage = slides.length === 1;
  var BASE_CLASS = cx('sui-ImageSlider', {
    'sui-ImageSlider--single': hasSingleImage
  });

  var buildCounter = function buildCounter(totalImages) {
    var classNames = cx('sui-ImageSlider-counter', "sui-ImageSlider-counter--" + counterPosition);
    var Icon = counterIcon;
    return /*#__PURE__*/React.createElement("div", {
      className: classNames
    }, /*#__PURE__*/React.createElement(Icon, {
      svgClass: "sui-ImageSlider-counterIcon"
    }), /*#__PURE__*/React.createElement("span", {
      className: "sui-ImageSlider-counterText"
    }, counterPatternFactory({
      current: currentSlide + 1,
      total: totalImages
    })));
  };

  var handleAfterSlide = function handleAfterSlide(_ref4) {
    var currentSlide = _ref4.currentSlide;
    setCurrentSlide(currentSlide);
    sliderOptions.doAfterSlide && sliderOptions.doAfterSlide(currentSlide);
  };

  return slides.length > 0 && /*#__PURE__*/React.createElement("div", {
    onClick: handleClick,
    className: BASE_CLASS
  }, slides.length > 1 ? /*#__PURE__*/React.createElement(ReactSlidy, Object.assign({}, sliderOptions, {
    doAfterSlide: handleAfterSlide
  }), slides) : slides, enableCounter && buildCounter(slides.length));
}
ImageSlider.displayName = 'ImageSlider';